# <img src="https://uploads-ssl.webflow.com/5ea5d3315186cf5ec60c3ee4/5edf1c94ce4c859f2b188094_logo.svg" alt="Pip.Services Logo" width="200"> <br/> IoC container for Python Changelog

## <a name="3.2.3"></a> 3.2.3 (2021-06-18)

### Bug fixes
* Fixed double logging when starts in container
* Fixed Container.open
* Fixed example

## <a name="3.2.1 - 3.2.2"></a> 3.2.1 - 3.2.2 (2021-06-17)

### Bug fixes
* Update requirements

## <a name="3.2.0"></a> 3.2.0 (2021-05-04)

### Bug fixes
* fixed names of private, protected and public properties and methods
* fixed interfaces method names

### Features
* added type hints

## <a name="3.1.8"></a> 3.1.8 (2021-04-23)

### Features
* updated DefaultContainerFactory, add factories

## <a name="3.1.7"></a> 3.1.7 (2021-04-23)

### Bug fixes
* fixed ManagedReferences close method

## <a name="3.1.6"></a> 3.1.6 (2021-04-22)

### Bug fixes
* fix DefaultInfoFactory import

## <a name="3.1.2-3.1.4"></a> 3.1.2-3.1.4 (2020-12-21)

### Bug Fixes
* a fixed config_path in ProcessContainer

## <a name="3.1.1"></a> 3.1.1 (2020-08-04)
* fixed config read in ContainerConfigReader.py and ProcessContainer.py

## <a name="3.0.0"></a> 3.0.0 (2018-11-18)

Initial public release

### Features
- **Build** - Container default factory
- **Config** - Container configuration
- **Refer** - Container references
- **Container** - components and manages their lifecycle
- **Proccess Container** - container that runs as a system process


